@@ -6,7 +6,7 @@ import pandas as pd
 import xml.dom
 import xml.dom.minidom
 
-from enum import Enum, auto
+from enum import Enum
 from datetime import datetime
 from glob import glob
 from collections import Mapping, defaultdict
@@ -26,13 +26,13 @@ class FormatNotSupportedError(NotImplementedError):
 
 
 class Format(Enum):
-    JSON = auto()
-    JSON_MIN = auto()
-    CSV = auto()
-    TSV = auto()
-    CONLL2003 = auto()
-    COCO = auto()
-    VOC = auto()
+    JSON = 1
+    JSON_MIN = 2
+    CSV = 3
+    TSV = 4
+    CONLL2003 = 5
+    COCO = 6
+    VOC = 7
 
     def __str__(self):
         return self.name
@@ -47,13 +47,16 @@ class Format(Enum):
 
 class Converter(object):
 
-    def __init__(self, config_string, output_tags=None):
-        if os.path.isfile(config_string):
-            with io.open(config_string) as f:
-                self._config_string = f.read()
-        else:
-            self._config_string = config_string
-        self._schema = parse_config(self._config_string)
+    def __init__(self, config, output_tags=None):
+        if isinstance(config, dict):
+            self._schema = config
+        elif isinstance(config, str):
+            if os.path.isfile(config):
+                with io.open(config) as f:
+                    config_string = f.read()
+            else:
+                config_string = config
+            self._schema = parse_config(config_string)
 
         self._data_keys, self._output_tags = self._get_data_keys_and_output_tags(output_tags)
         self._supported_formats = self._get_supported_formats()
@@ -95,20 +98,14 @@ class Converter(object):
         for name, info in self._schema.items():
             if output_tags is not None and name not in output_tags:
                 continue
-            new_data_keys = set(map(itemgetter('value'), info['inputs']))
-            if not data_keys:
-                data_keys |= new_data_keys
-            if data_keys != new_data_keys and output_tags is None:
-                raise ValueError(
-                    'Input schema for tag {name} differs from other tags: can\'t resolve data keys ambiguity. '
-                    'Check your input tag {input_tags}, or explicitly specify which '
-                    'output tag you wan\'t to save by using "output_tag" option'.format(
-                        name=name, input_tags=json.dumps(info['inputs'], indent=2)))
+            data_keys |= set(map(itemgetter('value'), info['inputs']))
             output_tag_names.append(name)
 
         return list(data_keys), output_tag_names
 
     def _get_supported_formats(self):
+        if len(self._data_keys) > 1:
+            return [Format.JSON.name, Format.JSON_MIN.name, Format.CSV.name, Format.TSV.name]
         output_tag_types = set()
         input_tag_types = set()
         for info in self._schema.values():
@@ -133,7 +130,8 @@ class Converter(object):
             raise FileNotFoundError('{input_dir} doesn\'t exist'.format(input_dir=input_dir))
         for json_file in glob(os.path.join(input_dir, '*.json')):
             for item in self.iter_from_json_file(json_file):
-                yield item
+                if item:
+                    yield item
 
     def iter_from_json_file(self, json_file):
         with io.open(json_file) as f:
@@ -155,9 +153,12 @@ class Converter(object):
                     'Currently only one completion could be added per task - '
                     'we can\'t convert more than one completions, but {num_completions} found in item: {item}'.format(
                         num_completions=len(d['completions']), item=json.dumps(d, indent=2)))
+            if d['completions'][0].get('skipped'):
+                return None
             result = d['completions'][0]['result']
         elif 'result' in d:
             result = d['result']
+
         inputs = d['data']
         outputs = defaultdict(list)
         for r in result:
@@ -175,6 +176,7 @@ class Converter(object):
 
     def _prettify(self, v):
         out = []
+        tag_type = None
         for i in v:
             j = deepcopy(i)
             tag_type = j.pop('type')
@@ -182,7 +184,7 @@ class Converter(object):
                 out.append(j['choices'][0])
             else:
                 out.append(j)
-        return out[0] if len(out) == 1 else out
+        return out[0] if tag_type == 'Choices' and len(out) == 1 else out
 
     def convert_to_json(self, input_dir, output_dir):
         self._check_format(Format.JSON)
@@ -209,7 +211,7 @@ class Converter(object):
             records.append(record)
 
         with io.open(output_file, mode='w') as fout:
-            json.dump(records, fout, indent=2)
+            json.dump(records, fout, indent=2, ensure_ascii=False)
 
     def convert_to_csv(self, input_data, output_dir, is_dir=True, **kwargs):
         self._check_format(Format.CSV)
@@ -238,7 +240,7 @@ class Converter(object):
             for item in item_iterator(input_data):
                 tokens, tags = create_tokens_and_tags(
                     text=item['input'][data_key],
-                    spans=next(iter(item['output'].values()))
+                    spans=next(iter(item['output'].values()), None)
                 )
                 for token, tag in zip(tokens, tags):
                     fout.write('{token} -X- _ {tag}\n'.format(token=token, tag=tag))
